# Anilistpy ![anilistpy](https://avatars3.githubusercontent.com/u/75199724?s=30&v=4)

[![Build Status](https://travis-ci.com/anilistpy/anilistpy.svg?branch=master)](https://travis-ci.com/anilistpy/anilistpy)
[![CodeFactor](https://www.codefactor.io/repository/github/anilistpy/anilistpy/badge)](https://www.codefactor.io/repository/github/anilistpy/anilistpy)
![PyPI - Downloads](https://img.shields.io/pypi/dm/anilistpy)
[![pypi verison](https://img.shields.io/pypi/v/anilistpy.svg)](https://pypi.org/project/anilistpy/)
[![GitHub license](https://img.shields.io/github/license/anilistpy/anilistpy)](https://github.com/anilistpy/anilistpy/blob/master/license)

An easy to use python3 wrapper for anilist.co APIv2 (UNOFFICIAL)

# Installing

## Installing from pypi

```
pip install anilistpy
```

## Installing from git
```
pip install git+https://github.com/anilistpy/anilistpy
```

## Installing from git (Unstable / Development branch)
```
pip install git+https://github.com/anilistpy/anilistpy@dev
```

# Getting started

# Importing

```py
import anilistpy
```

or manually import the method/class you need
```py
from anilistpy import Anime
```
 
More Documenation and Examples [here](https://anilistpy.github.io/)
(note: the Documenation is still being updated, if you need help make a issue)

# Change log 0.0.4 -> 0.0.5

- added wrappers for mutation api 
- more minor stuffs

![agpl3](https://upload.wikimedia.org/wikipedia/commons/thumb/0/06/AGPLv3_Logo.svg/200px-AGPLv3_Logo.svg.png)
